=======
History
=======

0.1.0 (2020-03-02)
------------------

* First release on PyPI.

1.2.0 (2020-06-10)
------------------

* Added support for referencing task using started by value

1.2.3 (2020-09-09)
------------------

* Make task parameter optional for service based deploys

1.3.0 (2020-10-22)
------------------

* Add support for authentication through aws sso

1.3.1 (2020-10-27)
------------------

* Add error logging for expired sso session
